#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY

#undef PACKAGE
#undef VERSION
#undef USE_CODEC
#undef USE_THREAD

#undef VMAID_BUILD_ENVIRONMENT

#undef HAVE_I386_SET_LDT
